% Class file derived from article by Peter Vassilev and Nikolay Ikonomov
% Class v.1.0
\ProvidesClass{bioauto}
\LoadClass[a4paper,12pt,fleqn]{article}

\PassOptionsToPackage{fleqn}{amsmath}
\PassOptionsToPackage{a4paper, top=2.5cm, bottom=2.5cm, left=2.5cm, right=2.5cm}{geometry}
\PassOptionsToPackage{usenames,dvipsnames}{xcolor}
\PassOptionsToPackage{T1}{fontenc}
\PassOptionsToPackage{sc}{mathpazo}

%\setcounter{errorcontextlines}{999}
%\RequirePackage{anyfontsize}
\RequirePackage{setspace}

\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{ifthen}
\RequirePackage{hyphenat}
\RequirePackage{url}
\RequirePackage{xcolor}
\RequirePackage{mathpazo}
\RequirePackage{fontenc}
\RequirePackage{mathptmx} 	
\RequirePackage{fancyhdr}
\RequirePackage{geometry}
\RequirePackage{graphicx}
\RequirePackage{hyperref}
%\RequirePackage{microtype}

%\DisableLigatures[fi]{encoding = *, family = *}

\setlength{\parindent}{0pt}
\setlength{\mathindent}{0pt}
\setlength{\parskip}{12pt}
\setcounter{secnumdepth}{0}

\hypersetup{
    bookmarks=true,         % show bookmarks bar?
    unicode=false,          % non-Latin characters in Acrobat�s bookmarks
    pdftoolbar=true,        % show Acrobat's toolbar?
    pdfmenubar=true,        % show Acrobat's menu?
    pdffitwindow=false,     % window fit to page when opened
    pdfstartview={FitH},    % fits the width of the page to the window
    pdfnewwindow=true,      % links in new window
    colorlinks=true,       % false: boxed links; true: colored links
    linkcolor=red,          % color of internal links
    citecolor=green,        % color of links to bibliography
    filecolor=magenta,      % color of file links
    urlcolor=blue           % color of external links
}


\definecolor{grn}{RGB}{0,128,0}
%baselinestretch
%\renewcommand{\baselinestretch}{1.005} 



%paragraph end space (define \parend )
%\newcommand{\parend}{\vspace{\baselineskip}}
%\RequirePackage{parskip}
%\addtolength{\parskip}{\baselineskip}


% Bibliography (no spacing)
% \let\newbibliography\thebibliography
% \renewcommand{\thebibliography}[1]{%
  % \newbibliography{#1}%
  % \setlength{\itemsep}{-1ex}%
% }



\renewenvironment{thebibliography}[1]
     {\section{\refname\vspace{-8pt}}%
      \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
			\setlength{\itemsep}{-1ex}%
			\setlength{\baselineskip}{14pt}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}
	  
%\renewcommand{\thebibliography}{\thebibliography\setlength{\itemsep}{-1ex}}
\renewcommand{\@biblabel}[1]{#1.\hspace{2mm}}
%\renewcommand{\refname}{}


% Header (from pdf file)
\newcommand{\BIOjournalYear}[1]{%
	\newcommand{\VAR@BIOjournalYear}{#1}%
}
\newcommand{\BIOjournalVolume}[1]{%
	\newcommand{\VAR@BIOjournalVolume}{#1}%
}
\newcommand{\BIOjournalNumber}[1]{%
	\newcommand{\VAR@BIOjournalNumber}{#1}%
}
\newcommand{\BIOjournalPages}[1]{%
	\newcommand{\VAR@BIOjournalPages}{#1}%
}

\pagestyle{fancy} 
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
\fancyhead{} % Clear all header fields
\fancyfoot{} % Clear all footer fields 
\newenvironment{correct}%
{\noindent\ignorespaces}%
{\par\noindent%
\ignorespacesafterend}


\headheight=41.7pt
\headsep=0pt

\fancyhead[L]{\hspace{1mm}\includegraphics[scale=0.027]{bioautomationgreen.pdf}
	{\hspace{2.2mm}{\bfseries \fontfamily{ppl}\fontsize{11pt}{11pt}\fontshape{it}\selectfont I%
	\fontsize{7pt}{7pt}\fontshape{it}\selectfont NT.
	\fontsize{11pt}{11pt}\fontshape{it}\selectfont J%
	\fontsize{7pt}{7pt}\fontshape{it}\selectfont .
	\fontsize{11pt}{11pt}\fontshape{it}\selectfont BIO%
	\fontsize{7pt}{7pt}\fontshape{it}\selectfont AUTOMATION,
	}%
	\fontfamily{ppl}\fontsize{9pt}{9pt}\fontshape{n}\selectfont\VAR@BIOjournalYear,
	\textbf{\VAR@BIOjournalVolume}(\VAR@BIOjournalNumber),
	\VAR@BIOjournalPages}\\[-3mm]
	{\color{grn}\rule{\textwidth}{1mm}}
}
\fancyfoot[C]{\thepage}


% Minipage
\newcounter{cauth}
\newcounter{caddr}
\newcounter{allauth}
\newcounter{alladdr}

\newcommand{\BIOtitle}[1]{%
	\newcommand{\intBIOtitle}{%
		\fontsize{16}{16}\selectfont\textbf{#1}%
	}%
}
% \newcommand{\BIOauthor}[1]{
	% \newcommand{\VAR@BIOauthor}{\fontsize{12}{12}\selectfont\textbf{#1}}
% }
% \newcommand{\BIOaddress}[1]{
	% \newcommand{\VAR@BIOaddress}{\fontsize{10}{10}\selectfont\textit{#1}}
% }
\newcommand{\BIOeditor}[3]{%
	\newcommand{\VAR@BIOeditor}{%
		\fontsize{10}{10}\selectfont\textbf{Received: #1 \hfill{Accepted: #2}\\[5mm]%
		\hbox{} \hfill{Published: #3}}%
	}%
}
\newcommand{\BIOabstract}[1]{%
	\newcommand{\VAR@BIOabstract}{%
		\fontsize{10}{10}\selectfont\textit{\textbf{Abstract:} #1}%
	}%
}
\newcommand{\BIOkeywords}[1]{%
	\newcommand{\VAR@BIOkeywords}{%
		\fontsize{10}{10}\selectfont\textit{\textbf{Keywords:} #1}%
	}%
}
%\newcommand{\WRITE@BIOauthor}{\BIOauthor}
%\whiledo{\value{cauth} < 2}{

\newcommand{\BIOauthors}[1]{%
	\newcommand{\intBIOauthors}{%
		\@for\@tempb:={#1}\do{%
			\addtocounter{allauth}{1}%
		}%
		\@for\@tempbio:={#1}\do{%
			\addtocounter{cauth}{1}%
			\fontsize{12}{12}\selectfont\textbf{\@tempbio}%
			\ifthenelse{\value{allauth}=1}{}{\textsuperscript{\arabic{cauth}}}%
			\ifthenelse{\value{cauth}=2}{\textsuperscript{*}}{}%
			\ifthenelse{\value{cauth}<\value{allauth}}{,}{}%
		}%
	}%
}


\newcommand{\BIOauthorEmail}[1]{
	\href{mailto:#1}{\underline{\smash{#1}}}
}
\newcommand{\BIOaddress}[1]{
	\newcommand{\intBIOaddress}{%
		\@for\@tempb:={#1}\do{%
			\addtocounter{alladdr}{1}%
		}%
		\@for\tempbio:={#1}\do{%
			\addtocounter{caddr}{1}%
			\ifthenelse{\value{alladdr}=1}{e}{{\fontsize{10}{10}\selectfont\textsuperscript{\arabic{caddr}}}}%
			{\fontsize{10}{10}\selectfont\textit{\tempbio}}%
			\ifthenelse{\value{caddr}<\value{alladdr}}{\\[10pt]}{}%
		}%
	}%
}
%\nohyphens{}
\newenvironment{biotitle}{%
\noindent\makebox[\textwidth][c]{%
	\begin{minipage}{0.825\textwidth}%
	\begin{spacing}{1.3}%
	\nohyphens{\intBIOtitle}\\%
	\end{spacing}%
		\intBIOauthors\\[14pt]%
	\intBIOaddress\\[10pt]%
	\fontsize{10}{10}\selectfont\textit{\textsuperscript{*}Corresponding author}\\[12pt]%
	\VAR@BIOeditor\\[12pt]%
	\VAR@BIOabstract\\[12pt]%
	\VAR@BIOkeywords\\%
	\end{minipage}%
	}%
}

\renewcommand{\section}[1]{%
	{\fontsize{14pt}{14pt}\selectfont\textbf{#1}}\vspace{-12pt}%
}
\renewcommand{\subsection}[1]{%
	{\fontsize{14pt}{14pt}\selectfont\textit{#1}}\vspace{-12pt}%
}
\renewcommand{\subsubsection}[1]{%
	{\fontsize{12pt}{12pt}\selectfont\textit{#1}}\vspace{-12pt}%
}

% \renewcommand\section{\@startsection {section}{1}{\z@}%
                                   % {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   % {0.001ex \@plus .2ex}%
                                   % {\fontsize{14pt}{14pt}\selectfont\bfseries}}
% \renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     % {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     % {0.001ex \@plus .2ex}%
                                     % {\fontsize{14pt}{14pt}\selectfont\it}}
% \renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     % {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     % {0.001ex \@plus .2ex}%
                                     % {\fontsize{12pt}{12pt}\selectfont\it}}





% Biography of the authors

\newcommand{\authorsNames}[1]{%
	\newcommand{\intAuthorsNames}{#1}%
}
\newcommand{\authorsEmails}[1]{%
	\newcommand{\intAuthorsEmails}{#1}%
}
\newcommand{\authorsPhotos}[2]{
	\newcommand{\intAuthorsPhotos}{#1}%
}
\newcommand{\authorsBios}[1]{
	\newcommand{\intAuthorsBios}{#1}%
}

\newcommand{\nophoto}{
	\setlength{\unitlength}{1cm}
	\begin{picture}(3,4)
	\put(0,0){\line(1,0){3}}
	\put(0,0){\line(0,1){4}}
	%\put(0,0){\line(3,4){3}}
	\put(0,4){\line(1,0){3}}
	%\put(3,0){\line(-3,4){3}}
	\put(3,0){\line(0,1){4}}
	\put(0.6,3){Place here}
	\put(0.4,2.5){a photograph}
	\put(0.45,2){of the author}
	\put(0.3,1.5){(no larger than}
	\put(0.8,1){$3 \times 4$ cm)}
	\end{picture}
}

\newcounter{bac}
\newcounter{cnt}
\newenvironment{biographyAuthors}{
\vspace{0.5cm}%
	\@for\i:=\intAuthorsNames\do{
		\addtocounter{bac}{1}
		%\ifthenelse{\equal{\i}{}}{}{
		\begin{tabular}{p{0.195\textwidth} p{0.75\textwidth}}
		% first row
		\multicolumn{2}{c}{\textbf{\i}} \\
		% second row
		\multicolumn{2}{c}{E-mail: %
			\setcounter{cnt}{0}%
			\@for\j:=\intAuthorsEmails\do{%
				\addtocounter{cnt}{1}%
				\ifthenelse{\value{cnt} = \value{bac}}{\j}{}%
			}%
		}\\
		% third row
		\setcounter{cnt}{0}%
		\@for\p:=\intAuthorsPhotos\do{%
			\addtocounter{cnt}{1}%
			\ifthenelse{\value{cnt} = \value{bac}}{
			\vspace{0pt}\ifthenelse{\equal{\p}{nophoto}}{\nophoto}{\includegraphics[bb=0 0 85 113,clip]{\p}}
			}{}%
		}%
		&
		% fourth row
		\setcounter{cnt}{0}%
		\@for\k:=\intAuthorsBios\do{%
			\addtocounter{cnt}{1}%
			\ifthenelse{\value{cnt} = \value{bac}}{\vspace{0pt}\k}{}%
		}%
		\end{tabular}
		\medskip
	}
	
	\addtocounter{bac}{1}
}

% end of file
